local mod = ...



-- Masterpiece conditions ------------------------------------------------------------------------------------
local function overrideMasterpiece(id, stat, pop)
    mod:overrideAsset({
        Id = id,
        UnlockCondition = {
            DataType = "GAME_CONDITION_VILLAGER_STATUS_REACHED",
            AssetVillagerStatus = stat,
            NumberRequired = pop,
        },
    })
end

overrideMasterpiece("MASTERPIECE_AUTOMATE_FOUNTAIN", "SERF", 100)
overrideMasterpiece("MASTERPIECE_SCULPTURE_FOUNTAIN", "SERF", 100)
overrideMasterpiece("MASTERPIECE_LUSH_GARDEN", "SERF", 200)
overrideMasterpiece("MASTERPIECE_CROSS", "SERF", 200)
overrideMasterpiece("MASTERPIECE_SHRINE", "SERF", 200)
overrideMasterpiece("MASTERPIECE_OFFICINAL_GARDEN", "SERF", 300)
overrideMasterpiece("MASTERPIECE_STAINED_GLASS", "SERF", 300)
overrideMasterpiece("MASTERPIECE_KNIGHT_STATUE", "SERF", 300)
-- overrideMasterpiece("MASTERPIECE_GATE", "SERF", 300)



-- Milestones: Kingdom ------------------------------------------------------------------------------------
local reward1 =                                     {
    DataType = "QUEST_REWARD_RESOURCES",
    BudgetCategory = "QUESTS",
    ResourceCollection = {
        {
            Resource = "GOLD_COINS",
            Quantity = 300
        },
        {
            Resource = "BREAD",
            Quantity = 100
        },
        {
            Resource = "BEER",
            Quantity = 60
        },
        {
            Resource = "BOAR",
            Quantity = 60
        },
    },
}

local reward2 =                                     {
    DataType = "QUEST_REWARD_RESOURCES",
    BudgetCategory = "QUESTS",
    ResourceCollection = {
        {
            Resource = "GOLD_COINS",
            Quantity = 400
        },
        {
            Resource = "CHEESE",
            Quantity = 200
        },
        {
            Resource = "WINE",
            Quantity = 100
        },
        {
            Resource = "CLOTHES",
            Quantity = 100
        },
    },
}

local reward3 = {
    DataType = "QUEST_REWARD_RESOURCES",
    BudgetCategory = "QUESTS",
    ResourceCollection = {
        {
            Resource = "GOLD_COINS",
            Quantity = 500
        },
        {
            Resource = "HONEY",
            Quantity = 100
        },
        {
            Resource = "HERBS",
            Quantity = 100
        },
    },
}


local function registerMilestoneKingdom(id, stat, pop, inf, rew)
    mod:registerAsset({
        DataType = "EVENT",
        Id = "EVENT_IAE_MILESTONE_" .. id,
        DaysToFirst = 1,
        ConditionList = {
            {
                DataType = "GAME_CONDITION_VILLAGER_STATUS_REACHED",
                AssetVillagerStatus = stat,
                NumberRequired = pop
            }
        },
        ActionList = {
            {
                DataType = "ACTION_SHOW_NARRATIVE_PANEL",
                NarrativePanelData = {
                    Title = "EVENT_IAE_MILESTONE_" .. id .. "_NAME",
                    Description = "EVENT_IAE_MILESTONE_" .. id .. "_DESC",
                    PanelVisual = "ILLUSTRATION_ESTATE_KING",
                },
                ChoiceList = {
                    {
                        ShortName = "TEXT_IAE_OK",
                        EventActionList = {
                            {
                                DataType = "EVENT_ACTION_GIVE_REWARD",
                                ActionList = {
                                    rew,
                                    {
                                        DataType = "GAME_ACTION_GIVE_TERRITORY",
                                        Amount = 1,
                                    },
                                    {
                                        DataType = "GAME_ACTION_GIVE_INFLUENCE",
                                        EstateInfluence = {
                                            Estate = "KINGDOM",
                                            Quantity = inf,
                                        },
                                    },
                                },
                            },
                        },
                    },
                },
            },
        }
    })

    mod:overrideAsset({
        Id = "DEFAULT_BALANCING",
        EventList = {
            Action = "APPEND",
            "EVENT_IAE_MILESTONE_" .. id,
        },
    })

end

registerMilestoneKingdom("1", "SERF", 100, 10, reward1)
registerMilestoneKingdom("2", "SERF", 200, 10, reward2)
registerMilestoneKingdom("3", "SERF", 300, 10, reward3)


mod:registerAsset({
    DataType = "EVENT",
    Id = "EVENT_IAE_MILESTONE_0",
    DaysToFirst = 1,
    ConditionList = {
        {
            DataType = "GAME_CONDITION_VILLAGER_STATUS_REACHED",
            AssetVillagerStatus = "NEWCOMER",
            NumberRequired = 30,
        }
    },
    ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                Title = "EVENT_IAE_MILESTONE_0_NAME",
                Description = "EVENT_IAE_MILESTONE_0_DESC",
                PanelVisual = "ILLUSTRATION_ESTATE_KING",
            },
            ChoiceList = {
                {
                    ShortName = "TEXT_IAE_OK",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_GIVE_REWARD",
                            ActionList = {
                                {
                                    DataType = "GAME_ACTION_GIVE_TERRITORY",
                                    Amount = 1,
                                },
                            },
                        },
                    },
                },
            },
        },
    }
})


mod:overrideAsset({
    Id = "DEFAULT_BALANCING",
    EventList = {
        Action = "APPEND",
        "EVENT_IAE_MILESTONE_0",
    },
})




-- Milestones: Clergy ------------------------------------------------------------------------------------
local function registerMilestoneClergy(id, build, inf)
    mod:registerAsset({
        DataType = "EVENT",
        Id = "EVENT_IAE_MILESTONE_" .. id,
        DaysToFirst = 1,
        ConditionList = {
            {
                DataType = "GAME_CONDITION_BUILDING_BUILT",
                AssetBuilding = build,
            }
        },
        ActionList = {
            {
                DataType = "ACTION_SHOW_NARRATIVE_PANEL",
                NarrativePanelData = {
                    Title = "EVENT_IAE_MILESTONE_" .. id .. "_NAME",
                    Description = "EVENT_IAE_MILESTONE_" .. id .. "_DESC",
                    PanelVisual = "ILLUSTRATION_ESTATE_CHURCH",
                },
                ChoiceList = {
                    {
                        ShortName = "TEXT_IAE_OK",
                        EventActionList = {
                            {
                                DataType = "EVENT_ACTION_GIVE_REWARD",
                                ActionList = {
                                    {
                                        DataType = "GAME_ACTION_GIVE_INFLUENCE",
                                        EstateInfluence = {
                                            Estate = "CLERGY",
                                            Quantity = inf,
                                        },
                                    },
                                },
                            },
                        },
                    },
                },
            },
        }
    })

    mod:overrideAsset({
        Id = "DEFAULT_BALANCING",
        EventList = {
            Action = "APPEND",
            "EVENT_IAE_MILESTONE_" .. id,
        },
    })

end

registerMilestoneClergy("4", "MONUMENT_RUSTIC_CHURCH", 10)
registerMilestoneClergy("5", "MONUMENT_LEGACY_RUSTIC_CHURCH", 10)
registerMilestoneClergy("6", "MONUMENT_ROMAN_CHURCH", 10)
registerMilestoneClergy("7", "MONUMENT_CHURCH", 20)



